@@ -3,9 +3,13 @@ package My::Module::Build;
 use strict;
 use warnings;
 
-use base qw{ Module::Build };
+use Module::Build;
+our @ISA = qw{ Module::Build };
 
 use Carp;
+# use lib 'inc';	# Already done because this module is running.
+use My::Module::Recommend;
+use My::Module::Test ();
 
 
 sub ACTION_authortest {
@@ -13,14 +17,35 @@ sub ACTION_authortest {
     my ( $self ) = @_;		# Arguments not used
 
     local $ENV{AUTHOR_TESTING} = 1;
+    local $ENV{SPACETRACK_IDENTITY} = undef;
+    local $ENV{SPACETRACK_OPT} = undef;
+
+    local $ENV{SPACETRACK_USER} = $ENV{SPACETRACK_USER};
+    My::Module::Test::spacetrack_user();
+
+    my @depends_on = ( qw{ build } );
+    -e 'META.json' or push @depends_on, 'distmeta';
+    $self->depends_on( @depends_on );
+
+    $self->test_files( qw{ t xt/author },
+	My::Module::Recommend->make_optional_modules_tests() );
 
-    $self->depends_on( 'build' );
-    $self->test_files( qw{ t xt/author } );
     $self->depends_on( 'test' );
 
     return;
 }
 
+sub harness_switches {
+    my ( $self ) = @_;
+    my @res = $self->SUPER::harness_switches();
+    foreach ( @res ) {
+	'-MDevel::Cover' eq $_
+	    or next;
+	$_ .= '=-db,cover_db,-ignore,inc/,-ignore,eg/';
+    }
+    return @res;
+}
+
 1;
 
 __END__
@@ -78,7 +103,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, 2011-2016 by Thomas R. Wyant, III
+Copyright (C) 2009, 2011-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
